package com.jiuqi.dna.ide.designer.workflow;

import com.jiuqi.dna.ide.designer.connection.IConnectionAnchorProvider;
import com.jiuqi.dna.ide.designer.connection.IConnectionProvider;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import com.jiuqi.dna.ide.designer.elements.IRootElement;
import com.jiuqi.dna.ide.designer.events.BendpointAdapter;
import com.jiuqi.dna.ide.designer.events.BendpointEvent;
import com.jiuqi.dna.ide.designer.events.DesignerElementAdapter;
import com.jiuqi.dna.ide.designer.events.DesignerElementEvent;
import com.jiuqi.dna.ide.designer.events.FigureAdapter;
import com.jiuqi.dna.ide.designer.events.FigureEvent;
import com.jiuqi.dna.ide.designer.events.IBendpointListener;
import com.jiuqi.dna.ide.designer.events.ICompositeListener;
import com.jiuqi.dna.ide.designer.events.IDesignerElementListener;
import com.jiuqi.dna.ide.designer.events.IFigureListener;
import com.jiuqi.dna.ide.designer.events.ILinkListener;
import com.jiuqi.dna.ide.designer.events.ISelectionListener;
import com.jiuqi.dna.ide.designer.events.LinkAdapter;
import com.jiuqi.dna.ide.designer.events.LinkEvent;
import com.jiuqi.dna.ide.designer.figure.IFigureProvider;
import com.jiuqi.dna.ide.designer.parts.DesignerEditPartFactory;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.draw2d.ChopboxAnchor;
import org.eclipse.draw2d.Connection;
import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.FreeformLayout;
import org.eclipse.draw2d.Graphics;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.MarginBorder;
import org.eclipse.draw2d.PolygonDecoration;
import org.eclipse.draw2d.PolylineConnection;
import org.eclipse.draw2d.RoutingAnimator;
import org.eclipse.gef.ContextMenuProvider;
import org.eclipse.gef.DefaultEditDomain;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.KeyHandler;
import org.eclipse.gef.KeyStroke;
import org.eclipse.gef.dnd.TemplateTransferDropTargetListener;
import org.eclipse.gef.editparts.ScalableFreeformRootEditPart;
import org.eclipse.gef.palette.PaletteRoot;
import org.eclipse.gef.requests.CreationFactory;
import org.eclipse.gef.requests.SimpleFactory;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.parts.GraphicalEditorWithPalette;
import org.eclipse.gef.ui.parts.GraphicalViewerKeyHandler;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.util.TransferDropTargetListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;

/* loaded from: com_jiuqi_dna_ide_designer_workflow.jar:com/jiuqi/dna/ide/designer/workflow/WorkflowDesigner.class */
public class WorkflowDesigner extends GraphicalEditorWithPalette {
    private static PaletteRoot PALETTE_MODEL;
    protected WorkflowDesignerBase designerBase = new WorkflowDesignerBase();
    private int paletteDockPosition = 16384;
    private boolean readOnly = false;
    private IDesignerElementListener elementListener = new DesignerElementAdapter() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.1
        public boolean verifyChangeProperty(DesignerElementEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }

        public boolean verifyCreate(DesignerElementEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }

        public boolean verifyDelete(DesignerElementEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }
    };
    private IFigureListener figureListener = new FigureAdapter() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.2
        public boolean verifyResize(FigureEvent event) {
            return false;
        }

        public boolean verifyMove(FigureEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }
    };
    private ILinkListener linkListener = new LinkAdapter() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.3
        public boolean verifyChange(LinkEvent event) {
            if (WorkflowDesigner.this.readOnly) {
                return false;
            }
            if (event.sourceChanged) {
                if (event.node.equals(event.link.getTarget())) {
                    return false;
                }
                Iterator it = event.node.getSourceLinks().iterator();
                while (it.hasNext()) {
                    ILinkElement lElem = (ILinkElement) it.next();
                    if (lElem.getTarget().equals(event.link.getTarget()) && !event.link.equals(lElem)) {
                        return false;
                    }
                }
            } else {
                if (event.node.equals(event.link.getSource())) {
                    return false;
                }
                Iterator it2 = event.node.getTargetLinks().iterator();
                while (it2.hasNext()) {
                    ILinkElement lElem2 = (ILinkElement) it2.next();
                    if (lElem2.getSource().equals(event.link.getSource()) && !event.link.equals(lElem2)) {
                        return false;
                    }
                }
            }
            return super.verifyChange(event);
        }

        public boolean verifyCreate(LinkEvent event) {
            if (WorkflowDesigner.this.readOnly) {
                return false;
            }
            ILinkElement link = event.link;
            Iterator it = link.getSource().getSourceLinks().iterator();
            while (it.hasNext()) {
                ILinkElement elem = (ILinkElement) it.next();
                if (link.equals(elem)) {
                    return false;
                }
            }
            return super.verifyCreate(event);
        }

        public boolean verifyDelete(LinkEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }
    };
    private IBendpointListener bendpointListener = new BendpointAdapter() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.4
        public boolean verifyChange(BendpointEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }

        public boolean verifyCreate(BendpointEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }

        public boolean verifyDelete(BendpointEvent event) {
            return !WorkflowDesigner.this.readOnly;
        }
    };
    private ISelectionChangedListener selectionChangeListener = new ISelectionChangedListener() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.5
        public void selectionChanged(SelectionChangedEvent e) {
            StructuredSelection selection = e.getSelection();
            if (WorkflowDesigner.this.designerBase != null && (selection instanceof StructuredSelection)) {
                StructuredSelection structuredSelection = selection;
                Object[] array = structuredSelection.toArray();
                IDesignerElement[] elements = new IDesignerElement[array.length];
                for (int i = 0; i < elements.length; i++) {
                    elements[i] = (IDesignerElement) ((EditPart) array[i]).getModel();
                }
                WorkflowDesigner.this.designerBase.setSelectedElements(elements);
            }
        }
    };

    public WorkflowDesigner() {
        setEditDomain(new DefaultEditDomain(this));
        getEditDomain().setPaletteRoot(getPaletteRoot());
        this.designerBase.addDesignerElementListener(this.elementListener);
        this.designerBase.addFigureListener(this.figureListener);
        this.designerBase.addLinkListener(this.linkListener);
        this.designerBase.addBendpointListener(this.bendpointListener);
    }

    protected boolean paletteDocksAtLeft() {
        return this.paletteDockPosition == 16384;
    }

    public int getPaletteDockPosition() {
        return this.paletteDockPosition;
    }

    public void setPaletteDockPosition(int paletteDockPosition) {
        this.paletteDockPosition = paletteDockPosition;
    }

    protected void configureGraphicalViewer() {
        super.configureGraphicalViewer();
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.setEditPartFactory(createEditPartFactory());
        viewer.setRootEditPart(new ScalableFreeformRootEditPart());
        viewer.setKeyHandler(createKeyHandler(viewer));
        viewer.addSelectionChangedListener(this.selectionChangeListener);
        ContextMenuProvider cmProvider = new WorkflowDesignerContextMenuProvider(viewer, this);
        viewer.setContextMenu(cmProvider);
    }

    protected EditPartFactory createEditPartFactory() {
        DesignerEditPartFactory editPartFactory = new DesignerEditPartFactory();
        editPartFactory.setFigureProvider(new IFigureProvider() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.6
            public IFigure getFigure(IFigureElement element) {
                IFigure figure;
                if (element instanceof IRootElement) {
                    figure = new FreeformLayer() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.6.1
                        protected void paintFigure(Graphics graphics) {
                            graphics.setAntialias(1);
                            super.paintFigure(graphics);
                        }
                    };
                    figure.setBorder(new MarginBorder(3));
                    figure.setLayoutManager(new FreeformLayout());
                } else {
                    IFigure workflowNodeFigure = new WorkflowNodeFigure();
                    workflowNodeFigure.setFigureElement(element);
                    figure = workflowNodeFigure;
                }
                return figure;
            }
        });
        editPartFactory.setConnectionAnchorProvider(new IConnectionAnchorProvider() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.7
            public ConnectionAnchor getConnectionAnchor(IFigureElement element, IFigure figure) {
                return new ChopboxAnchor(figure);
            }
        });
        editPartFactory.setConnectionProvider(new IConnectionProvider() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.8
            public Connection getConnection(ILinkElement link) {
                PolylineConnection conn = new PolylineConnection() { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.8.1
                    public void paintFigure(Graphics graphics) {
                        graphics.setAntialias(1);
                        super.paintFigure(graphics);
                    }
                };
                conn.addRoutingListener(RoutingAnimator.getDefault());
                conn.setTargetDecoration(new PolygonDecoration());
                return conn;
            }
        });
        return editPartFactory;
    }

    protected KeyHandler createKeyHandler(GraphicalViewer viewer) {
        GraphicalViewerKeyHandler keyHandler = new GraphicalViewerKeyHandler(viewer);
        ActionRegistry registry = getActionRegistry();
        keyHandler.put(KeyStroke.getPressed((char) 127, 127, 0), registry.getAction("delete"));
        keyHandler.put(KeyStroke.getPressed((char) 1, 97, 262144), registry.getAction("selectAll"));
        keyHandler.put(KeyStroke.getPressed((char) 25, 121, 262144), registry.getAction("redo"));
        keyHandler.put(KeyStroke.getPressed((char) 26, 122, 262144), registry.getAction("undo"));
        return keyHandler;
    }

    protected void createActions() {
        super.createActions();
        ActionRegistry registry = getActionRegistry();
        IAction action = registry.getAction("undo");
        this.designerBase.addContextMenuAction("com.jiuqi.dna.ide.group.undo", action);
        IAction action2 = registry.getAction("redo");
        this.designerBase.addContextMenuAction("com.jiuqi.dna.ide.group.undo", action2);
        IAction action3 = registry.getAction("selectAll");
        this.designerBase.addContextMenuAction("com.jiuqi.dna.ide.group.rest", action3);
        IAction action4 = registry.getAction("delete");
        this.designerBase.addContextMenuAction("com.jiuqi.dna.ide.group.edit", action4);
    }

    private TransferDropTargetListener createTransferDropTargetListener() {
        return new TemplateTransferDropTargetListener(getGraphicalViewer()) { // from class: com.jiuqi.dna.ide.designer.workflow.WorkflowDesigner.9
            protected CreationFactory getFactory(Object template) {
                return new SimpleFactory((Class) template);
            }
        };
    }

    protected PaletteRoot getPaletteRoot() {
        if (PALETTE_MODEL == null) {
            PALETTE_MODEL = WorkflowDesignerPaletteFactory.createPalette(this.designerBase);
        }
        return PALETTE_MODEL;
    }

    protected void initializeGraphicalViewer() {
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.setContents(getRootElement());
        viewer.addDropTargetListener(createTransferDropTargetListener());
    }

    public void doSave(IProgressMonitor monitor) {
    }

    protected EditPart getEditPart(IDesignerElement element) {
        EditPart editpart;
        GraphicalViewer viewer = getGraphicalViewer();
        EditPart root = viewer.getRootEditPart();
        if (root.getModel() == element) {
            editpart = root;
        } else {
            editpart = getEditPart(element, root);
        }
        return editpart;
    }

    private EditPart getEditPart(IDesignerElement element, EditPart parent) {
        List<?> children = parent.getChildren();
        for (Object obj : children) {
            if (obj instanceof EditPart) {
                EditPart child = (EditPart) obj;
                if (child.getModel() == element) {
                    return child;
                }
                EditPart editpart = getEditPart(element, child);
                if (editpart != null) {
                    return editpart;
                }
            }
        }
        return null;
    }

    public void addDesignerElementListener(IDesignerElementListener listener) {
        this.designerBase.addDesignerElementListener(listener);
    }

    public void removeDesignerElementListener(IDesignerElementListener listener) {
        this.designerBase.removeDesignerElementListener(listener);
    }

    public void addFigureListener(IFigureListener listener) {
        this.designerBase.addFigureListener(listener);
    }

    public void removeFigureListener(IFigureListener listener) {
        this.designerBase.removeFigureListener(listener);
    }

    public void addCompositeListener(ICompositeListener listener) {
        this.designerBase.addCompositeListener(listener);
    }

    public void removeCompositeListener(ICompositeListener listener) {
        this.designerBase.removeCompositeListener(listener);
    }

    public void addSelectionListener(ISelectionListener listener) {
        this.designerBase.addSelectionListener(listener);
    }

    public void removeSelectionListener(ISelectionListener listener) {
        this.designerBase.removeSelectionListener(listener);
    }

    public IRootElement getRootElement() {
        return this.designerBase.getRootElement();
    }

    public <T extends IDesignerElement> T createElement(Class<T> cls) {
        return (T) this.designerBase.createElement(cls);
    }

    public void setRootElement(IRootElement rootElement) {
        this.designerBase.setRootElement(rootElement);
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.setContents(getRootElement());
        viewer.flush();
    }

    public void addSelectedElement(IDesignerElement element) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.appendSelection(getEditPart(element));
        this.designerBase.addSelectedElement(element);
    }

    public void addSelectedElements(IDesignerElement[] elements) {
        if (elements == null) {
            throw new NullPointerException("参数elements不能为NULL！");
        }
        GraphicalViewer viewer = getGraphicalViewer();
        for (IDesignerElement element : elements) {
            viewer.appendSelection(getEditPart(element));
        }
        this.designerBase.addSelectedElements(elements);
    }

    public IDesignerElement[] getSelectedElements() {
        return this.designerBase.getSelectedElements();
    }

    public void setSelectedElement(IDesignerElement element) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        setSelectedElements(new IDesignerElement[]{element});
    }

    public void setSelectedElements(IDesignerElement[] elements) {
        if (elements == null) {
            throw new NullPointerException("参数elements不能为NULL！");
        }
        ArrayList<EditPart> list = new ArrayList<>(elements.length);
        for (IDesignerElement element : elements) {
            list.add(getEditPart(element));
        }
        StructuredSelection selection = new StructuredSelection(list);
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.setSelection(selection);
        this.designerBase.setSelectedElements(elements);
    }

    public void removeSelectedElement(IDesignerElement element) {
        GraphicalViewer viewer = getGraphicalViewer();
        viewer.deselect(getEditPart(element));
        this.designerBase.removeSelectedElement(element);
    }

    public void addContextMenuAction(String groupName, IAction action, int type) {
        this.designerBase.addContextMenuAction(groupName, action);
        ActionRegistry registry = getActionRegistry();
        registry.registerAction(action);
        if ((1 & type) != 0) {
            getSelectionActions().add(action.getId());
        }
        if ((2 & type) != 0) {
            getStackActions().add(action.getId());
        }
    }

    public IAction removeContextMenuAction(String groupName, String actionId) {
        IAction action = this.designerBase.getContextMenuAction(groupName, actionId);
        if (action != null) {
            ActionRegistry registry = getActionRegistry();
            registry.removeAction(action);
        }
        return this.designerBase.removeContextMenuAction(groupName, actionId);
    }

    public IAction[] removeContextMenuGroup(String groupName) {
        IAction[] group = getMenuGroup(groupName);
        if (group != null) {
            ActionRegistry registry = getActionRegistry();
            for (IAction action : group) {
                registry.removeAction(action);
            }
        }
        return this.designerBase.removeContextMenuGroup(groupName);
    }

    public String[] getMenuGroupNames() {
        return this.designerBase.getMenuGroupNames();
    }

    public IAction[] getMenuGroup(String groupName) {
        return this.designerBase.getMenuGroup(groupName);
    }

    public boolean isReadOnly() {
        return this.readOnly;
    }

    public void setReadOnly(boolean readOnly) {
        this.readOnly = readOnly;
        getPaletteViewer().getControl().setEnabled(!readOnly);
    }
}
